@@ -140,6 +140,18 @@ public:
 
     void switchActiveView();
 
+    /**
+     * Overwrites the automatically generated label of this tab with @p label.
+     * This @p label will be kept until it is overwritten by calling this method again.
+     * Calling this with an empty string will restore the automatic labelling.
+     */
+    void setCustomLabel(const QString &label);
+
+    /**
+     * @see setCustomLabel.
+     */
+    QString customLabel() const;
+
 Q_SIGNALS:
     void activeViewChanged(DolphinViewContainer *viewContainer);
     void activeViewUrlChanged(const QUrl &url);
@@ -201,6 +213,8 @@ private:
     bool m_primaryViewActive;
     bool m_splitViewEnabled;
     bool m_active;
+    /** @see setCustomLabel(). */
+    QString m_customLabel;
 };
 
 class DolphinTabPageSplitterHandle : public QSplitterHandle
