@@ -13,7 +13,7 @@
 #include "private/kitemlistsmoothscroller.h"
 
 #ifndef QT_NO_ACCESSIBILITY
-#include <QAccessibleEvent>
+#include "accessibility/kitemlistviewaccessible.h"
 #endif
 #include <QApplication>
 #include <QFontMetrics>
@@ -202,11 +202,11 @@ void KItemListContainer::focusInEvent(QFocusEvent *event)
         // We need to set the focus to the view or accessibility software will only announce the container (which has no information available itself).
         // For some reason actively setting the focus to the view needs to be delayed or the focus will immediately go back to this container.
         QTimer::singleShot(0, this, [this, view]() {
-            view->setFocus();
+            if (!isAncestorOf(QApplication::focusWidget())) {
+                view->setFocus();
+            }
 #ifndef QT_NO_ACCESSIBILITY
-            QAccessibleEvent accessibleFocusInEvent(this, QAccessible::Focus);
-            accessibleFocusInEvent.setChild(0);
-            QAccessible::updateAccessibility(&accessibleFocusInEvent);
+            static_cast<KItemListViewAccessible *>(QAccessible::queryAccessibleInterface(view))->setAccessibleFocusAndAnnounceAll();
 #endif
         });
     }
@@ -291,6 +291,9 @@ void KItemListContainer::updateScrollOffsetScrollBar()
     int maximum = 0;
     if (view->scrollOrientation() == Qt::Vertical) {
         smoothScroller = m_verticalSmoothScroller;
+        if (smoothScroller->isAnimating()) {
+            return;
+        }
         scrollOffsetScrollBar = verticalScrollBar();
 
         // Don't scroll super fast when using a wheel mouse:
@@ -311,6 +314,9 @@ void KItemListContainer::updateScrollOffsetScrollBar()
         maximum = qMax(0, int(view->maximumScrollOffset() - view->size().height()));
     } else {
         smoothScroller = m_horizontalSmoothScroller;
+        if (smoothScroller->isAnimating()) {
+            return;
+        }
         scrollOffsetScrollBar = horizontalScrollBar();
         singleStep = view->itemSize().width();
         pageStep = view->size().width();
@@ -347,11 +353,17 @@ void KItemListContainer::updateItemOffsetScrollBar()
     int pageStep = 0;
     if (view->scrollOrientation() == Qt::Vertical) {
         smoothScroller = m_horizontalSmoothScroller;
+        if (smoothScroller->isAnimating()) {
+            return;
+        }
         itemOffsetScrollBar = horizontalScrollBar();
         singleStep = view->size().width() / 10;
         pageStep = view->size().width();
     } else {
         smoothScroller = m_verticalSmoothScroller;
+        if (smoothScroller->isAnimating()) {
+            return;
+        }
         itemOffsetScrollBar = verticalScrollBar();
         singleStep = view->size().height() / 10;
         pageStep = view->size().height();
