@@ -81,8 +81,9 @@ public:
     void setColumnWidth(const QByteArray &role, qreal width);
     qreal columnWidth(const QByteArray &role) const;
 
-    void setSidePadding(qreal width);
-    qreal sidePadding() const;
+    void setSidePadding(qreal leftPaddingWidth, qreal rightPaddingWidth);
+    qreal leftPadding() const;
+    qreal rightPadding() const;
 
     void setStyleOption(const KItemListStyleOption &option);
     const KItemListStyleOption &styleOption() const;
@@ -202,7 +203,7 @@ protected:
     virtual void dataChanged(const QHash<QByteArray, QVariant> &current, const QSet<QByteArray> &roles = QSet<QByteArray>());
     virtual void visibleRolesChanged(const QList<QByteArray> &current, const QList<QByteArray> &previous);
     virtual void columnWidthChanged(const QByteArray &role, qreal current, qreal previous);
-    virtual void sidePaddingChanged(qreal width);
+    virtual void sidePaddingChanged(qreal leftPaddingWidth, qreal rightPaddingWidth);
     virtual void styleOptionChanged(const KItemListStyleOption &current, const KItemListStyleOption &previous);
     virtual void currentChanged(bool current);
     virtual void selectedChanged(bool selected);
@@ -263,7 +264,8 @@ private:
     QHash<QByteArray, QVariant> m_data;
     QList<QByteArray> m_visibleRoles;
     QHash<QByteArray, qreal> m_columnWidths;
-    qreal m_sidePadding;
+    qreal m_leftPadding;
+    qreal m_rightPadding;
     KItemListStyleOption m_styleOption;
     QBitArray m_siblingsInfo;
 
