@@ -158,8 +158,8 @@ protected:
     void setTextColor(const QColor &color);
     QColor textColor(const QWidget &widget) const;
 
-    void setOverlay(const QPixmap &overlay);
-    QPixmap overlay() const;
+    void setOverlays(QHash<Qt::Corner, QString> &overlay);
+    QHash<Qt::Corner, QString> overlays() const;
 
     /**
      * @see KStandardItemListWidgetInformant::roleText().
@@ -176,7 +176,7 @@ protected:
     void dataChanged(const QHash<QByteArray, QVariant> &current, const QSet<QByteArray> &roles = QSet<QByteArray>()) override;
     void visibleRolesChanged(const QList<QByteArray> &current, const QList<QByteArray> &previous) override;
     void columnWidthChanged(const QByteArray &role, qreal current, qreal previous) override;
-    void sidePaddingChanged(qreal width) override;
+    void sidePaddingChanged(qreal leftPaddingWidth, qreal rightPaddingWidth) override;
     void styleOptionChanged(const KItemListStyleOption &current, const KItemListStyleOption &previous) override;
     void hoveredChanged(bool hovered) override;
     void selectedChanged(bool selected) override;
@@ -212,13 +212,18 @@ private:
     void updateCompactLayoutTextCache();
     void updateDetailsLayoutTextCache();
 
+    QPixmap addOverlays(const QPixmap &pixmap,
+                        const QHash<Qt::Corner, QString> &overlays,
+                        const QSize &size,
+                        qreal devicePixelRatioF,
+                        QIcon::Mode mode = QIcon::Normal) const;
+
     void drawPixmap(QPainter *painter, const QPixmap &pixmap);
+    /** Draw the lines and arrows that visualize the expanded state and level of this row. */
     void drawSiblingsInformation(QPainter *painter);
 
     QRectF roleEditingRect(const QByteArray &role) const;
 
-    QString elideRightKeepExtension(const QString &text, int elidingWidth) const;
-
     /**
      * Escapes text for display purposes.
      *
@@ -232,7 +237,7 @@ private:
      */
     void closeRoleEditor();
 
-    QPixmap pixmapForIcon(const QString &name, const QStringList &overlays, int size, QIcon::Mode mode) const;
+    QPixmap pixmapForIcon(const QString &name, const QSize &size, QIcon::Mode mode) const;
 
     /**
      * @return Preferred size of the rating-image based on the given
@@ -284,7 +289,7 @@ private:
     QColor m_customTextColor;
     QColor m_additionalInfoTextColor;
 
-    QPixmap m_overlay;
+    QHash<Qt::Corner, QString> m_overlays;
     QPixmap m_rating;
 
     KItemListRoleEditor *m_roleEditor;
