@@ -10,7 +10,6 @@
 #define PLACESPANEL_H
 
 #include "panels/panel.h"
-#include "views/draganddrophelper.h"
 
 #include <KFilePlacesView>
 #include <QUrl>
@@ -79,8 +78,6 @@ private:
     QAction *m_configureTrashAction;
     QAction *m_openInSplitView;
     QAction *m_lockPanelsAction;
-
-    DragAndDropHelper m_dragAndDropHelper;
 };
 
 #endif // PLACESPANEL_H
